<?php
/**
 * Template Name: Gallery Page
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Theme Palace
 */

get_header();
do_action( 'photo_fusion_pro_banner_section' );

$options = photo_fusion_pro_get_theme_options();

// portfolio type
$gallery_content_type    = $options['gallery_content_type'];
$gallery_img_layout      = $options['gallery_image_layout'];
$paged = ( get_query_var('paged' ) ) ? get_query_var('paged') : 1;

$args = array(
	'ignore_sticky_posts'=> true,
	'post_type'         => 'post',
	'posts_per_page'    => 8,
	'category__in'      => $gallery_content_type,
	'paged'    			=> $paged,
);

if( ! empty ( $args ) ) :
$i = 1; 
$img_count = 1;
?>

<section id="portfolio" class="bg-white">
	<div class="page-section">
		<div class="entry-content">
			<nav class="portfolio-filter os-animation" data-os-animation="fadeInDown" data-os-animation-delay="0.1s" data-os-animation-duration="2s">
				<ul>
					<li><a href="#" data-filter="*" class="active"><?php esc_html_e( 'All', 'photo-fusion-pro' ); ?></a></li>
					<?php
					if ( ! empty( $gallery_content_type ) ) :
						foreach ( $gallery_content_type as $tp_cat_id ) {
							$tp_category = get_category( $tp_cat_id );
							echo '<li><a href="#" data-filter=".' . esc_attr( $tp_category->slug ) . '">' . esc_html( $tp_category->name ) . '</a></li>';
						}
					endif;
					?>
				</ul>
			</nav><!-- end .portfolio-filter -->

			<div id="fourcol" class="tp-portfolio os-animation" data-os-animation="fadeIn" data-os-animation-delay="0.1s" data-os-animation-duration="2s">
			<?php
			// The Query
			$gallery_query = new WP_Query( $args );

			if ( $gallery_query->have_posts() ) :
				// The Loop
				while ( $gallery_query->have_posts() ) : $gallery_query->the_post();
					if ( has_post_thumbnail() ) {
						if ( $img_count == 9 ) :
							$img_count = 1;
						endif;
						if ( $gallery_img_layout == 'grid' ) {
							$tp_image_type = 'grid';
						} else {
							$tp_image_type = ( $img_count == 2 || $img_count == 4 || $img_count == 7 || $img_count == 8 ) ? 'grid' : 'condensed';
						}

						$img_array = wp_get_attachment_image_src( get_post_thumbnail_id(), 'photo-fusion-pro-portfolio-' . $tp_image_type );
						$img_array_large = wp_get_attachment_image_src( get_post_thumbnail_id(), 'large' );
					} else {
						if ( $gallery_img_layout == 'grid' ) {
	                        $tp_image_size = '300x300';
	                    } else {
	                        $tp_image_size = ( $img_count == 2 || $img_count == 4 || $img_count == 7 || $img_count == 8 ) ? '300x300' : '300x379';
	                    }
	                     $img_array[0]        = get_template_directory_uri().'/assets/uploads/no-featured-image-'.$tp_image_size.'.png';
	                     $img_array_large[0]  = get_template_directory_uri().'/assets/uploads/no-featured-image-'.$tp_image_size.'.png';
						}					
						
						$post_categories = get_the_category();
						
						if( ! empty( $img_array[0] ) ): 
						?>
							<div class="box item-w1 <?php echo ( $img_count == 2 || $img_count == 4 || $img_count == 7 || $img_count == 8 ) ? ' item-h2 ' : ' item-h1 ';
								foreach ( $post_categories as $post_category ) {
									$category_slug = $post_category->slug;
									echo esc_attr( $category_slug ) . ' ';
								} ?>">
							<figure>
								<a href="#">
									<img src="<?php echo esc_url( $img_array[0] ); ?>" alt="<?php echo esc_attr( get_the_title() ); ?>">
									<div class="red-overlay"></div><!-- end .red-overlay -->
								</a>
								<figcaption>
									<div class="popup-image">
										<a href="<?php echo esc_url( $img_array_large[0] ); ?>" data-lightbox="masonry"><i class="fa fa-eye"></i></a>
										<a href="<?php echo esc_url( get_permalink() ); ?>"><i class="fa fa-link"></i></a>
									</div><!-- end .popup-image -->

									<div class="portfolio-content">
										<div class="tag">
											<small>
												<?php
												$no_of_cat = 1;
			                                    foreach ( $post_categories as $post_category ) {
			                                        $category_id   = $post_category->term_id;
			                                        $category_name = $post_category->name;
			                                        $category_url  = get_category_link( $category_id );

			                                        echo ' <a href="' . esc_url( $category_url ) . '">'. esc_html( $category_name ) . '</a>';
			                                        if( $no_of_cat == 5 ) break;
			                                        $no_of_cat++;
			                                    } 
												?>
											</small>
										</div>
										<div class="portfolio-title">
											<a href="<?php echo esc_url( get_permalink() ); ?>"><h4><?php echo esc_html( get_the_title() ); ?></h4></a>
										</div><!-- end .portfolio-title -->

										<div class="portfolio-desc">
											<p class="desc"><?php echo esc_html( photo_fusion_pro_trim_content( $post, absint( $options['excerpt_length'] ) ) ); ?></p>
										</div><!-- end .portfolio-title -->
									</div><!-- end .portfolio-content -->
								</figcaption>
							</figure>
						</div><!-- end box -->
					<?php endif; $img_count++; $i++;
				endwhile;
				
				/* Restore original Post Data 
				 * NB: Because we are using new WP_Query we aren't stomping on the 
				 * original $wp_query and it does not need to be reset with 
				 * wp_reset_query(). We just need to set the post data back up with
				 * wp_reset_postdata().
				 */
				wp_reset_postdata();
			endif; ?>	
			</div><!-- end portfolio -->
			<?php if ( $gallery_query->max_num_pages > 1 ) : ?>
				<nav class="navigation pagination" role="navigation">
				    <h2 class="screen-reader-text"><?php esc_html_e( 'Posts Navigation','photo-fusion-pro' ); ?></h2>
				    <div class="nav-links">
				        <?php
				        $big = 999999999; // need an unlikely integer
				        echo paginate_links( array(
				                'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
				                'format' => '?paged=%#%',
				                'current' => max( 1, get_query_var('paged') ),
				                'total' => $gallery_query->max_num_pages,
				                'prev_text' => '<span class="btn fill btn-js">' . esc_html__( 'Previous','photo-fusion-pro' ) . '</span>',
								'next_text' => '<span class="btn fill btn-js">' . esc_html__( 'Next', 'photo-fusion-pro' ) . '</span>',
								'before_page_number' => '<span class="btn fill btn-js">',
				    			'after_page_number'	 => '</span>',
				            ) );
				        ?>
				    </div>
				</nav>
			<?php endif; ?>
		</div><!-- end .entry-content -->
	</div><!-- end .container -->
	<div class="clear"></div>
</section>

<?php
endif;
get_footer();