<?php
/**
 * Photo Gallery Customizer options
 *
 * @package Theme Palace
 * @subpackage Photo Fusion Pro
 * @since Photo Fusion Pro 1.0
 */

// Add photo gallery enable section
$wp_customize->add_section( 'photo_fusion_pro_photo_gallery_section', array(
	'title'             => esc_html__( 'Photo Gallery','photo-fusion-pro' ),
	'description'       => esc_html__( 'Photo gallery section options.', 'photo-fusion-pro' ),
	'panel'             => 'photo_fusion_pro_sections_panel'
) );

// Add photo gallery enable setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[photo_gallery_enable]', array(
	'default'           => $options['photo_gallery_enable'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_select'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[photo_gallery_enable]', array(
	'label'             => esc_html__( 'Enable on', 'photo-fusion-pro' ),
	'section'           => 'photo_fusion_pro_photo_gallery_section',
	'type'              => 'select',
	'choices'           => photo_fusion_pro_enable_disable_options()
) );

// Add photo gallery source
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[photo_gallery_source]', array(
	'default'           => $options['photo_gallery_source'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_select'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[photo_gallery_source]', array(
	'label'             => esc_html__( 'Photo Gallery Source', 'photo-fusion-pro' ),
	'section'           => 'photo_fusion_pro_photo_gallery_section',
	'type'              => 'select',
	'choices'           => photo_fusion_pro_photo_gallery_source(),
	'active_callback' => 'photo_fusion_pro_photo_gallery_active', 
) );

// Add photo gallery post image layout.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[photo_gallery_image_layout]', array(
	'default'           => $options['photo_gallery_image_layout'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_select'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[photo_gallery_image_layout]', array(
	'label'             => esc_html__( 'Select Image Layout', 'photo-fusion-pro' ),
	'section'           => 'photo_fusion_pro_photo_gallery_section',
	'type'              => 'select',
	'choices'           => photo_fusion_pro_photo_gallery_image_layout(),
	'active_callback' => 'photo_fusion_pro_photo_gallery_source_not_demo', 
) );

// Add photo gallery post image layout.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[photo_gallery_no_of_img]', array(
	'default'           => $options['photo_gallery_no_of_img'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_number_range',
	'validate_callback' => 'photo_fusion_pro_validate_no_of_photo_gallery',

) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[photo_gallery_no_of_img]', array(
	'label'             => esc_html__( 'No of Images', 'photo-fusion-pro' ),
	'description'       => esc_html__( 'For Masonary 11 images is default.', 'photo-fusion-pro' ),
	'section'           => 'photo_fusion_pro_photo_gallery_section',
	'type'              => 'number',
	'input_attrs'		=> array(
		'min'          	=> 4,
		'max' 			=> 50,
		'style'        	=> 'width: 80px;'
	),
	'active_callback' => 'photo_fusion_pro_photo_gallery_layout', 
) );

// Add photo gallery content type setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[photo_gallery_content_type]', array(
	'sanitize_callback' => 'photo_fusion_pro_sanitize_category_list'
) );

$wp_customize->add_control( new photo_fusion_pro_Dropdown_Category_Control( $wp_customize, 'photo_fusion_pro_theme_options[photo_gallery_content_type]', array(
	'label'           => esc_html__( 'Select categories', 'photo-fusion-pro' ),
	'description'     => esc_html__( 'Note: Press shift key and select multiple categories. Latest posts form the selected categories will be shown.', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_photo_gallery_section',
	'type'            => 'dropdown-categories',
	'active_callback' => 'photo_fusion_pro_photo_gallery_source_category', 
) ) );

$photo_gallery_no_of_image     = ( $options['photo_gallery_image_layout'] == 'grid' ) ? $options['photo_gallery_no_of_img'] : 11;

for ( $i = 1; $i <= $photo_gallery_no_of_image; $i++ ) {

	// Slider post hr setting and control
   	$wp_customize->add_setting( 'photo_fusion_pro_theme_options[photo_gallery_categories_hr_'. $i .']', array(
    		'sanitize_callback' => 'sanitize_text_field'
   	) );
   
   	$wp_customize->add_control( new photo_fusion_pro_Customize_Horizontal_Line( $wp_customize, 'photo_fusion_pro_theme_options[photo_gallery_categories_hr_'. $i .']',
   		array(
   			'section'         	=> 'photo_fusion_pro_photo_gallery_section',
   			'active_callback' 	=> 'photo_fusion_pro_photo_gallery_source_category_list',
   			'type'				=> 'hr'
    	) ) );
	
	// Add photo gallery content type setting and control.
	$wp_customize->add_setting( 'photo_fusion_pro_theme_options[photo_gallery_categories_' . $i . ']', array(
		'sanitize_callback' => 'photo_fusion_pro_sanitize_single_category'
	) );

	$wp_customize->add_control( new photo_fusion_pro_Dropdown_Taxonomies_Control( $wp_customize, 'photo_fusion_pro_theme_options[photo_gallery_categories_' . $i . ']', array(
		'label'       		=> sprintf( esc_html__( 'Select Category %d', 'photo-fusion-pro' ), $i ),
		'section'         => 'photo_fusion_pro_photo_gallery_section',
		'type'            => 'dropdown-taxonomies',
		'active_callback' => 'photo_fusion_pro_photo_gallery_source_category_list', 
	) ) );

	// Slider Section background setting and control.
	$wp_customize->add_setting( 'photo_fusion_pro_theme_options[photo_gallery_categories_image_' . $i . ']', array(
		'sanitize_callback' => 'photo_fusion_pro_sanitize_image'
	) );

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'photo_fusion_pro_theme_options[photo_gallery_categories_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Select Image %d', 'photo-fusion-pro' ), $i ),
			'section'     		=> 'photo_fusion_pro_photo_gallery_section',
			'active_callback'	=> 'photo_fusion_pro_photo_gallery_source_category_list',
	) ) );

}
