<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Theme Palace
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function photo_fusion_pro_body_classes( $classes ) {
	$options = photo_fusion_pro_get_theme_options();
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	$sidebar_position = $options['sidebar_position'];
	$sidebar_position = apply_filters( 'photo_fusion_pro_sidebar_position', $sidebar_position );
	// Check if single.
	if ( is_singular() ) {
		$post_sidebar_position = get_post_meta( get_the_ID(), 'photo-fusion-pro-sidebar-position', true );
		if ( isset( $post_sidebar_position ) && ! empty( $post_sidebar_position ) ) {
			$sidebar_position = $post_sidebar_position;
		}
	}

	if ( is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = esc_attr( $sidebar_position );
	} else {
		$classes[] = 'no-sidebar';
	}

	if( $options['slider_enable'] != 'disabled' && $options['about_enable'] == 'disabled'  && ( $options['photo_gallery_enable'] != 'disabled' || $options['portfolio_enable'] != 'disabled' || $options['blog_enable'] == true ) ){
        $classes[] = 'about-us-disabled';
    }

    // Add a class for gallery section gap 
	$classes[] = ! empty( $options['gallery_with_gap'] ) ? esc_attr( $options['gallery_with_gap'] ) : 'gallery-no-gap';

	$photo_gallery_image_layout    = ( $options['photo_gallery_source'] == 'demo' ) ? 'masonry' : $options['photo_gallery_image_layout'];
	if ( 'grid' == $photo_gallery_image_layout ) {
		$classes[] = 'grid-box';
	}

	// Add a class for typography
	$classes[] = esc_attr( $options['theme_typography'] );

	$classes[] = esc_attr( $options['site_layout'] );

	return $classes;
}
add_filter( 'body_class', 'photo_fusion_pro_body_classes' );